@@ -15,7 +15,7 @@ package config
 
 import (
 	"fmt"
-	"io/ioutil"
+	"os"
 	"regexp"
 	"time"
 
@@ -24,7 +24,7 @@ import (
 )
 
 func LoadFile(filename string) (*Config, error) {
-	content, err := ioutil.ReadFile(filename)
+	content, err := os.ReadFile(filename)
 	if err != nil {
 		return nil, err
 	}
@@ -37,6 +37,8 @@ func LoadFile(filename string) (*Config, error) {
 }
 
 var (
+	defaultRetries int = 3
+
 	DefaultAuth = Auth{
 		Community:     "public",
 		SecurityLevel: "noAuthNoPriv",
@@ -44,11 +46,13 @@ var (
 		PrivProtocol:  "DES",
 	}
 	DefaultWalkParams = WalkParams{
-		Version:        2,
-		MaxRepetitions: 25,
-		Retries:        3,
-		Timeout:        time.Second * 5,
-		Auth:           DefaultAuth,
+		Version:                 2,
+		MaxRepetitions:          25,
+		Retries:                 &defaultRetries,
+		Timeout:                 time.Second * 5,
+		Auth:                    DefaultAuth,
+		UseUnconnectedUDPSocket: false,
+		AllowNonIncreasingOIDs:  false,
 	}
 	DefaultModule = Module{
 		WalkParams: DefaultWalkParams,
@@ -62,11 +66,13 @@ var (
 type Config map[string]*Module
 
 type WalkParams struct {
-	Version        int           `yaml:"version,omitempty"`
-	MaxRepetitions uint8         `yaml:"max_repetitions,omitempty"`
-	Retries        int           `yaml:"retries,omitempty"`
-	Timeout        time.Duration `yaml:"timeout,omitempty"`
-	Auth           Auth          `yaml:"auth,omitempty"`
+	Version                 int           `yaml:"version,omitempty"`
+	MaxRepetitions          uint32        `yaml:"max_repetitions,omitempty"`
+	Retries                 *int          `yaml:"retries,omitempty"`
+	Timeout                 time.Duration `yaml:"timeout,omitempty"`
+	Auth                    Auth          `yaml:"auth,omitempty"`
+	UseUnconnectedUDPSocket bool          `yaml:"use_unconnected_udp_socket,omitempty"`
+	AllowNonIncreasingOIDs  bool          `yaml:"allow_nonincreasing_oids,omitempty"`
 }
 
 type Module struct {
@@ -95,7 +101,7 @@ func (c *Module) UnmarshalYAML(unmarshal func(interface{}) error) error {
 			if wp.Auth.PrivPassword == "" {
 				return fmt.Errorf("priv password is missing, required for SNMPv3 with priv")
 			}
-			if wp.Auth.PrivProtocol != "DES" && wp.Auth.PrivProtocol != "AES" && wp.Auth.PrivProtocol != "AES192" && wp.Auth.PrivProtocol != "AES256" {
+			if wp.Auth.PrivProtocol != "DES" && wp.Auth.PrivProtocol != "AES" && wp.Auth.PrivProtocol != "AES192" && wp.Auth.PrivProtocol != "AES192C" && wp.Auth.PrivProtocol != "AES256" && wp.Auth.PrivProtocol != "AES256C" {
 				return fmt.Errorf("priv protocol must be DES or AES")
 			}
 			fallthrough
@@ -174,8 +180,12 @@ func (c WalkParams) ConfigureSNMP(g *gosnmp.GoSNMP) {
 			usm.PrivacyProtocol = gosnmp.AES
 		case "AES192":
 			usm.PrivacyProtocol = gosnmp.AES192
+		case "AES192C":
+			usm.PrivacyProtocol = gosnmp.AES192C
 		case "AES256":
 			usm.PrivacyProtocol = gosnmp.AES256
+		case "AES256C":
+			usm.PrivacyProtocol = gosnmp.AES256C
 		}
 	}
 	g.SecurityParameters = usm
